@@ -23,7 +23,7 @@
 #include <locale>
 #include <testsuite_hooks.h>
 
-void test01()
+void test02()
 {
   using namespace std;
   bool test __attribute__((unused)) = true;
@@ -32,16 +32,18 @@ void test01()
   locale loc(locale("en_US.UTF-8"));
   fb.pubimbue(loc);
   fb.pubsetbuf(0, 0);
-  fb.open("tmp_11305-1", ios_base::out);
+  fb.open("tmp_11305-2", ios_base::out);
   wfilebuf::int_type n1 = fb.sputc(0x20000000);
+  wfilebuf::int_type n2 = fb.sputc(0x40000000);
   wfilebuf* f = fb.close();
   
   VERIFY( n1 != wfilebuf::traits_type::eof() );
+  VERIFY( n2 != wfilebuf::traits_type::eof() );
   VERIFY( f != NULL );
 }
 
 int main()
 {
-  test01();
+  test02();
   return 0;
 }
